/*
 * SPDX-FileCopyrightText: Copyright 2022, 2024 Arm Limited and/or its affiliates <open-source-office@arm.com>
 * SPDX-License-Identifier: Apache-2.0
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
#ifndef OBJ_DET_HANDLER_HPP
#define OBJ_DET_HANDLER_HPP

#if VSI_ENABLED
#include "DetectionResult.hpp"
#include <vector>
#endif

#include <cstdint>
#include "AppContext.hpp"

namespace arm {
namespace app {

#if VSI_ENABLED
    typedef object_detection::DetectionResult OdResults;

    /**
     * @brief       Draw boxe(s) detected by the model.
     * @param[in]   image        Pointer to the image.
     * @param[in]   imageWidth   Image width.
     * @param[in]   imageHeight  Image height.
     * @param[in]   results      A vector of detection results.
     **/
    void DrawDetectionBoxesVsi(uint8_t* image,
                               const uint32_t imageWidth,
                               const uint32_t imageHeight,
                               const std::vector<OdResults>& results);
    /**
     * @brief       Handles the inference event when using VSI.
     * @param[in]   ctx        Pointer to the application context.
     * @return      true or false based on execution success.
     **/
    bool ObjectDetectionHandlerVsi(ApplicationContext& ctx);
#endif

    /**
     * @brief       Handles the inference event.
     * @param[in]   ctx        Pointer to the application context.
     * @param[in]   imgIndex   Index to the image to run object detection.
     * @param[in]   runAll     Flag to request classification of all the available images.
     * @return      true or false based on execution success.
     **/
    bool ObjectDetectionHandler(ApplicationContext& ctx, uint32_t imgIndex, bool runAll);

} /* namespace app */
} /* namespace arm */

#endif /* OBJ_DET_HANDLER_HPP */
